==> haskell-cheapskate-0.1.1.1-85-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1.1
id: cheapskate-0.1.1.1-3geWrSVplmqD3AZZwq6Y7h
key: cheapskate-0.1.1.1-3geWrSVplmqD3AZZwq6Y7h
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: 1deb4ab11da353e9ad065bc04babcea1
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cheapskate-0.1.1.1
hs-libraries: HScheapskate-0.1.1.1-3geWrSVplmqD3AZZwq6Y7h
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    containers-0.6.0.1 data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    text-1.2.3.1 uniplate-1.6.12-BTaZBg5AycHDY52rt8gZNP
    xss-sanitize-0.3.6-5Bg9vxiQErB9FeMVIRu8G6
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.1-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1.1
id: cheapskate-0.1.1.1-3f1rsEwMu1DG66RABo7LVL
key: cheapskate-0.1.1.1-3f1rsEwMu1DG66RABo7LVL
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: 944ceff0e3899db37093eac3e0341702
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cheapskate-0.1.1.1
hs-libraries: HScheapskate-0.1.1.1-3f1rsEwMu1DG66RABo7LVL
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    containers-0.6.0.1 data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    text-1.2.3.1 uniplate-1.6.12-BTaZBg5AycHDY52rt8gZNP
    xss-sanitize-0.3.6-5Bg9vxiQErB9FeMVIRu8G6
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
